@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 2000/03/21 15:53:09 $
-# $Revision: 1.18.1.192 $
+# $Date: 2002/01/18 12:22:22 $
+# $Revision: 1.18.1.199 $
 #
 #
 package provide zircon 1.18
@@ -18,8 +18,8 @@ proc nil {op args} {
     opText -
     addText {global currentNet ; eval [$currentNet info] addText $args}
     osTag { return [lindex $args 1] }
-    default { error "***** \007\007 nil called : $op $args" }
-    }	
+    }
+    error "***** \007\007 nil called : $op $args"
 }
 #
 proc getDefault {var net} {
@@ -41,7 +41,7 @@ proc Channel {name args} {
 #
 proc cleanup {name} {
     set pattern "\[ ,\n\r\]"
-    regsub -all $pattern $name {} name
+    regsub -all -- $pattern $name {} name
     return $name
 }
 #
@@ -62,6 +62,7 @@ proc channel_popPalette {this prt x y} {
 #
 proc channel_makePalette {this prt} {
     global Ft
+    # FRINK : array Ft
     makePalette .@pal$this$prt $this $prt "[$this name] $prt" $Ft($this) [$this colour]
 }
 #
@@ -108,10 +109,11 @@ proc channel_drawSet {this} {
 proc makeChannel {chan} {
     set this [objName Channel]
     initObj $this Channel
-    proc $this {op args} "objCall channel $this \$op \$args"
+    proc $this {unusedop args} "objCall channel $this \$unusedop \$args"
     set lchan [string tolower $chan]
     upvar #0 currentNet net
     upvar #0 $this cdata CTO$net CTO
+    # FRINK : array cdata
     catch {array set cdata [uplevel #0 array get [getDefault defChan $net]] }
     array set cdata [list \
 	name	$chan \
@@ -202,12 +204,12 @@ proc channel_active {this} {
     return 1
 }
 #
-proc channel_setTopic {this string} {
+proc channel_setTopic {this str} {
     if {![winfo exists [set w [$this window].topic.entry]]} return
     set state [$w cget -state]
     $w configure -state normal
     $w delete 1.0 end
-    insertText $this $w $string {}
+    insertText $this $w $str {}
     $this topicState $state
 }
 #
@@ -218,11 +220,11 @@ proc channel_changeMode {this mode} {
     [$this net] MODE [$this name] [expr {$val ? {+} : {-}}]${mode}
 }
 #
-proc channel_optText {this name string} {
-    if {[$this wantMessage $name]} { $this addText @$name $string }
+proc channel_optText {this name str} {
+    if {[$this wantMessage $name]} { $this addText @$name $str }
 }
 #
-proc channel_addText {this tag text} {
+proc channel_addText {this tag txt} {
     switch {} [set win [$this window]] {} default {
 	if {[$this open] && ![winfo ismapped $win]} {
 	    if {[[$this net] noPopup]} {
@@ -239,32 +241,32 @@ proc channel_addText {this tag text} {
 	    }
 	}
     }
-    $this doAddText $tag $text
+    $this doAddText $tag $txt
 }
 #
-proc channel_send {this string args} {
+proc channel_send {this str args} {
     global user host
-    switch {} $string {} default {
+    switch {} $str {} default {
 	global Secure
-	$this addHist $string
+	$this addHist $str
 	set lc [$this lname]
 	set rchan [expr \
 	  {[info exists Secure($lc)] ? $Secure($lc) : [$this name]}]
 	set net [$this net]
 	switch {} [set key [$this crypt]] {
-	    $net q1Send "PRIVMSG $rchan :$string"
+	    $net q1Send "PRIVMSG $rchan :$str"
 	} default {
-	    set gsh $string
+	    set gsh $str
 	    $net q1Send "PRIVMSG $rchan :[encrypt $gsh $key]"
 	}
 	regsub -all %n [$this mytag] [[$net myid] name] pr
 	switch -- $args {} {
-	    $this addText @me "$pr $string"
+	    $this addText @me "$pr $str"
 	} default {
-	    $this doAddText @me "$pr $string"
+	    $this doAddText @me "$pr $str"
 	}
 	if {[$this selfpattern]} {
-	    doPatterns $this [[$net myid] name]!$user@$host $string
+	    doPatterns $this [[$net myid] name]!$user@$host $str
 	}
     }
 }
@@ -331,7 +333,6 @@ proc channel_doNames {this param} {
 	}
 	set usr [User :: make $net $n]
 	switch $usr $myid {
-	    upvar #0 $this cdata
 	    set cdata(Op,$myid) $op
 	    set cdata(Spk,$myid) $sp
 	    if {$op} { $this markOp $usr } elseif {$sp} { $this markV $usr }
@@ -391,8 +392,7 @@ proc channel_doJoin {this usr nm prefix ov} {
     if {![$this isJoined $usr]} {
 	$this optText JOIN \
 	  "*** [$usr name] ($nm) has joined channel [$this name]"
-	$this addUser $usr 0 0
-	$usr ref
+	$this addUser [$usr ref] 0 0
     } {
 	upvar #0 $this cdata
 	set w $cdata(window)
@@ -409,7 +409,7 @@ proc channel_doJoin {this usr nm prefix ov} {
     $this handleOV $ov $usr
     $this setOps $prefix $usr
     foreach x [$this ban] {
-	if {[regexp -nocase [lindex $x 0] $prefix]} {
+	if {[regexp -nocase -- [lindex $x 0] $prefix]} {
 	    set net [$this net]
 	    $net q1Send "MODE [$this name] +b [lindex $x 1]"
 	    $net q1Send "KICK [$this name] [$usr name] :Ban List for [$this name]"
@@ -463,13 +463,13 @@ proc channel_configure {this args} {
 	}
 	-scrollback {
 	    switch {} $val { set val 0 }
-	    if {$val < 0} { set val 0 }
+	    if {$val < 0} { set val [expr {-$val}] }
 	    set cdata(scrollback) $val
 	}
 	-ban {
 		set cdata(ban) {}
 		foreach x $val {
-		    if {[catch {regexp -nocase [set v [lindex $x 0]] abcde}]} {
+		    if {[catch {regexp -nocase -- [set v [lindex $x 0]] abcde}]} {
 			tellError {} {Ban List Error} "Bad regular\
 expression in -ban for channel [$this name] - \"$v\""
 			continue
@@ -485,7 +485,7 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 	-ops {
 		set cdata(ops) {}
 		foreach x [fixList $val] {
-		    if {[catch {regexp -nocase $x abcde}]} {
+		    if {[catch {regexp -nocase -- $x abcde}]} {
 			tellError {} {Ops Error} "Bad regular expression in -ops for channel [$this name] - \"$x\""
 		    } {
 			lappend cdata(ops) $x
@@ -609,7 +609,7 @@ proc channel_setTitles {this} {
    return [list [$this name] [$this name]]
 }
 #
-proc makeCUsers  {this net w chan rchan idx cdx look} {
+proc makeCUsers  {this unusednet w unusedchan unusedrchan idx cdx look} {
     set f [frame $w.r$idx.uFrm -borderwidth 2 -relief raised]
     $this configure -ufrm $f
     scrollbar $f.vs -command "$f.userBtn yview" 
@@ -632,7 +632,7 @@ proc makeCUsers  {this net w chan rchan idx cdx look} {
     if {$on} {grid $f -row 0 -column $cdx -sticky nsew}
 }
 #
-proc makeCTopic {this net w chan rchan idx cdx look} {
+proc makeCTopic {this net w unusedchan unusedrchan idx cdx unusedlook} {
     grid columnconfigure $w.r$idx $cdx -weight 1
     frame $w.topic -borderwidth 0
     grid columnconfigure $w.topic 1 -weight 1
@@ -657,13 +657,13 @@ proc makeCTopic {this net w chan rchan idx cdx look} {
     grid $w.topic -sticky ew -column $cdx -row 0 -in $w.r$idx
 }
 #
-proc makeCText {this net w chan rchan idx cdx look} {
+proc makeCText {this net w unusedchan unusedrchan idx cdx look} {
     global zLock zUnlock TypeCode
     set f [frame $w.r$idx.textFrm -borderwidth 0]
     grid rowconfigure $f 0 -weight 1
     $this configure -text [set ot $f.$TypeCode([$this type])]
     scrollbar $f.vs -command "$ot yview"
-    text $ot -yscrollcommand "setScroll $this $ot $f.vs" \
+    text $ot -yscrollcommand "$f.vs set" \
       -width [$this width] -height [$this height]
     setProps $this $ot
     rebind $ot $net
@@ -721,11 +721,11 @@ proc makeBindTopic {this} {
     switch {} $Ft($this) {} default { $w configure -font $Ft($this) }
 }
 #
-proc makeBindInfo {this} { } 
+proc makeBindInfo {unusedthis} { } 
 #
-proc makeBindPopper {this} { }
+proc makeBindPopper {unusedthis} { }
 #
-proc makeBindFlags {this} { }
+proc makeBindFlags {unusedthis} { }
 #
 proc makeBindEntry {this} {
     global Fg Bg Ft BF
@@ -735,11 +735,12 @@ proc makeBindEntry {this} {
     switch {} $Ft($this) {} default { $w configure -font $Ft($this) }
 }
 #
-proc makeBindControl {this} { }
+proc makeBindControl {unusedthis} { }
 #
-proc makeBindUsers {this} { }
+proc makeBindUsers {unusedthis} { }
 #
 proc makeBindText {this} {
+    upvar #0 $this cdata
     set tgw [$this tagWindow]
     set ot [$this text]
     foreach tag {foreground background font selectForeground
@@ -792,7 +793,7 @@ proc channel_remove {this usr} {
     }
 }
 #
-proc makeCEntry {this net w chan rchan idx cdx look} {
+proc makeCEntry {this net w chan unusedrchan idx cdx look} {
     global zII zNOII zLock zUnlock
     grid columnconfigure $w.r$idx $cdx -weight 1
     set om [frame $w.cmd -borderwidth 0]
@@ -816,7 +817,7 @@ proc makeCEntry {this net w chan rchan idx cdx look} {
     grid $om -sticky ew -row 0 -column $cdx -in $w.r$idx
 }
 #
-proc makeCtlMode {this net w chan rchan idx look} {
+proc makeCtlMode {this net w unusedchan rchan idx unusedlook} {
     upvar #0 $this cdata
     set om [makeMB $w.mode Mode]
     addImage $w.mode mode $w.cmds $idx $net
@@ -860,7 +861,7 @@ proc makeCtlMode {this net w chan rchan idx look} {
     }
 }
 #
-proc makeCtlInfo {this net w chan rchan idx look} {
+proc makeCtlInfo {this net w chan rchan idx unusedlook} {
     if {[$this isa Channel]} {
 	set om [makeMB $w.channel Channel]
 	addImage $w.channel channel $w.cmds $idx $net
@@ -913,7 +914,7 @@ proc makeCtlInfo {this net w chan rchan idx look} {
     if {[$this isa Chat]} { $om entryconfigure last -state disabled }
 }
 #
-proc makeCtlAction {this net w chan rchan idx look} {
+proc makeCtlAction {this net w chan unusedrchan idx unusedlook} {
     set om [makeMB $w.action Action]
     catch {$w.action.menu configure -tearoffcommand "retitle {Actions for $chan}"}
     addImage $w.action action $w.cmds $idx $net
@@ -925,7 +926,7 @@ proc makeCtlAction {this net w chan rchan idx look} {
     }
 }
 #
-proc makeCtlUsers {this net w chan rchan idx look} {
+proc makeCtlUsers {this net w unusedchan unusedrchan idx unusedlook} {
     $this buildUsersMenu [makeMB $w.users Names]
     addImage $w.users names $w.cmds $idx $net
 }
@@ -937,7 +938,7 @@ proc buttonHack {btn cmd} {
     $btn configure -command $sc
 }
 #
-proc makeCtlQuit {this net w chan rchan idx look} {
+proc makeCtlQuit {this net w unusedchan unusedrchan idx unusedlook} {
     buttonmenu $w.quit -command "$this leave" -text [trans leave]
     bind $w.quit <Shift-1> [bind Button <1>]
     bind $w.quit <Shift-ButtonRelease-1> "buttonHack %W {$net quit}"
@@ -974,7 +975,7 @@ proc makeCtlQuit {this net w chan rchan idx look} {
     addImage $w.quit leave $w.cmds $idx $net
 }
 #
-proc makeCtlClear {this net w chan rchan idx look} {
+proc makeCtlClear {this net w unusedchan unusedrchan idx unusedlook} {
     button $w.clear -command "$this clear 0" -text [trans clear]
     addImage $w.clear clear $w.cmds $idx $net
     bind $w.clear <Shift-1> [bind Button <1>]
@@ -986,12 +987,12 @@ proc makeCtlClear {this net w chan rchan idx look} {
     "
 }
 #
-proc makeCFlags {this net w chan rchan idx cdx look} {
+proc makeCFlags {unusedthis unusednet w unusedchan unusedrchan idx cdx look} {
     grid [frame $w.cflags -borderwidth 0] -row 0 -column $cdx -in $w.r$idx
     foreach x [lindex $look 0] { label $w.cflags.$x -relief flat }
 }
 #
-proc makeCInfo {this net w chan rchan idx cdx look} {
+proc makeCInfo {unusedthis unusednet w unusedchan unusedrchan idx cdx look} {
     grid [frame $w.cinfo -borderwidth 0] -row 0 -column $cdx -in $w.r$idx
     grid columnconfigure $w.r$idx $cdx -weight 1
     foreach x [lindex $look 0] { label $w.cinfo.$x -relief flat }
@@ -1007,7 +1008,7 @@ proc makeCControl {this net w chan rchan idx cdx look} {
     grid $w.cmds -row 0 -column $cdx -sticky ew -in $w.r$idx
 }
 #
-proc rowHide {this net w idx} {
+proc rowHide {unusedthis unusednet w idx} {
     grid remove $w.r$idx
     if {![winfo exists $w.phide]} {
 	grid [frame $w.phide -borderwidth 0 -relief flat] \
@@ -1022,14 +1023,14 @@ proc rowHide {this net w idx} {
     "
 }
 #
-proc makeCPopper {this net w chan rchan idx cdx look} {
+proc makeCPopper {this net w unusedchan unusedrchan idx cdx unusedlook} {
     grid [frame $w.p$idx -relief raised -borderwidth 2] \
       -row 0 -column $cdx -in $w.r$idx -sticky ns -ipadx 3
     grid columnconfigure $w.r$idx $cdx -weight 0
     bind $w.p$idx <1> "rowHide $this $net $w $idx"
 }
 #
-proc makeCBody {this w rchan chan net opts look} {
+proc makeCBody {this w rchan chan net unusedopts look} {
     grid columnconfigure $w 0 -weight 1
     set idx 0
     foreach x $look {
@@ -1080,12 +1081,12 @@ proc lclTrace {chan var} {
     }
 }
 #
-proc updVar {chan n1 n2 op} {
+proc updVar {chan unused n2 unused2} {
     upvar #0 $chan cdata
     set cdata(lcl$n2) $cdata($n2)
 }
 #
-proc unsVar {chan n1 n2 op} { uplevel #0 unset ${this}(lcl$n2) }
+proc unsVar {chan unused n2 unused2} { uplevel #0 unset ${chan}(lcl$n2) }
 #
 proc channel_buildUsersMenu {this w} {
     upvar #0 $this cdata
@@ -1168,7 +1169,7 @@ proc channel_sizeHistory {this} {
     tkwait window .@sh$this
 }
 #
-proc pickOut {net win pos} {
+proc pickOut {unused win pos} {
     switch -glob -- [set txt [$win get "$pos linestart" "$pos lineend"]] {
     {[=->]*} { return [string range $txt 2 end] }
     {!>*} { return [string range $txt 3 end] }
@@ -1178,9 +1179,9 @@ proc pickOut {net win pos} {
     return $txt
 }
 #
-proc channel_addHist {this string} {
+proc channel_addHist {this str} {
     upvar #0 $this cdata
-    set cdata(histbuff) [lrange [linsert $cdata(histbuff) 0 $string] 0 $cdata(history)]
+    set cdata(histbuff) [lrange [linsert $cdata(histbuff) 0 $str] 0 $cdata(history)]
     set cdata(hpos) -1
 }
 #
@@ -1239,7 +1240,7 @@ proc channel_leave {this} {
       [list cancel {}]
 }
 #
-proc channel_doAddText {this tag text} {
+proc channel_doAddText {this tag txt} {
     upvar #0 $this cdata
     switch {} [set name [$this text]] return
     if {[catch {$name configure -state normal}]} {
@@ -1251,11 +1252,11 @@ proc channel_doAddText {this tag text} {
     } {
 	set time {}
     }
-    insertText $this $name $text $tag
+    insertText $this $name $txt $tag
     $name insert end "\n"
     if {$cdata(scrollback)} { $name delete 1.0 "end - $cdata(scrollback)lines" }
     $name configure -state disabled
-    $this log $time$text
+    $this log $time$txt
     if {$cdata(jump)} {$name see end}
 }
 #
@@ -1274,11 +1275,11 @@ proc channel_getAction {this} {
 #
 # Send string to channel as an ACTION and echo to channel window
 #
-proc channel_action {this string} {
-    switch {} $string {} default {
-	[$this net] q1Send "PRIVMSG [$this name] :\001ACTION $string\001"
-	$this addText @me "* [[$this net] nickname] $string"
-	$this addHist $string
+proc channel_action {this str} {
+    if {$str != {}} {
+	[$this net] q1Send "PRIVMSG [$this name] :\001ACTION $str\001"
+	$this addText @me "* [[$this net] nickname] $str"
+	$this addHist $str
     }
 }
 #
@@ -1310,20 +1311,20 @@ and you won't see this message..." info 0 \
     }
 }
 #
-proc channel_insert {this text} {
+proc channel_insert {this txt} {
     if {[$this m] && ![$this operator] && ![$this speaker]} return
-    switch {} $text {} default {
+    if {$txt != {}} {
 	set op send
 	if {[$this actionmode]} { set op action }
 	set ent [$this window].cmd.entry
-	while {[regexp "(\[^\n\]*)\n(.*)" $text d line text]} {
+	while {[regexp "(\[^\n\]*)\n(.*)" $txt d line txt]} {
 	    switch -- $line {} continue
 	    tkEntryInsert $ent $line
 	    $this $op [$ent get]
 	    $ent delete 0 end
 	}
-	switch {} $text {} default {
-	    $ent insert insert $text
+	if {$txt != {}} {
+	    $ent insert insert $txt
 	    tkEntrySeeInsert $ent
 	}
     }
@@ -1446,8 +1447,8 @@ proc channel_nickChange {this usr nnk} {
 #
 proc nop {args} { return 1}
 #
-proc cpriv {chan op spk menu x} {
-    return [cpriv1 $chan $op $spk [winfo name [$menu entrycget $x -menu]]]
+proc cpriv {chan op spk menuw x} {
+    return [cpriv1 $chan $op $spk [winfo name [$menuw entrycget $x -menu]]]
 }
 #
 proc cpriv1 {chan op spk usr2} {
@@ -1637,9 +1638,8 @@ proc channel_userMode {this usr mode} {
 proc channel_setOps {this prefix usr} {
     upvar #0 MkOp[$this net] MkOp
     foreach n [$this ops] {
-	if {[regexp -nocase $n $prefix]} {
-	    lappend MkOp($this) $usr
-	    $usr ref
+	if {[regexp -nocase -- $n $prefix]} {
+	    lappend MkOp($this) [$usr ref]
 	    break
 	}
     }
@@ -1854,9 +1854,9 @@ proc channel_save {this desc} {
     }
 }
 #
-proc defSave {desc array net TVar} {
+proc defSave {desc arry net TVar} {
     global zDefs defaultNet Channel
-    upvar #0 $TVar conf $array defObj
+    upvar #0 $TVar conf $arry defObj
     array set zDefs $Channel
     array set zDefs $conf
     set adf $defObj($defaultNet)
@@ -1892,13 +1892,13 @@ proc Channel_pack {net} { foreach ch [$net channels] { $ch pack new }}
 #
 proc channel_pack {this where} {
     if {![$this isa Channel]} return
-    global $where$this $this
-    array set $where$this [array get $this]
+    upvar #0 $where$this to $this from
+    # FRINK : array to from
+    array set to [array get from]
 }
 #
 proc channel_unpack {this where} {
-    upvar #0 $where$this new
-    upvar #0 Configure.Channel config
+    upvar #0 $where$this new Configure.Channel config
     foreach prop [array names config] {
 	$this configure -$prop $new($prop)
     }
@@ -1991,7 +1991,7 @@ proc channel_search {this} {
       -row 5 -column 1 -sticky ew
 }
 #
-proc channel_doSearch {this w args} {
+proc channel_doSearch {this unused args} {
     global Search
     set cmd {}
     if {$Search($this,case)} { lappend cmd -nocase }
@@ -2012,25 +2012,25 @@ proc channel_doHi {this txt} {
     set t [$this text]
     $t tag delete @hilite@
     set res 1.0
-    while 1 { switch {} [set res [$t search -- $txt $res]] break }
+    while {1} { switch {} [set res [$t search -- $txt $res]] break }
 }
 #
-proc checkJoinTime {this time} {
-    switch {} $time return
+proc checkJoinTime {this timev} {
+    if {$timev == {}} { return 1 }
     upvar #0 $this cdata
-    if {[catch {set tt [clock scan $time]}]} {
+    if {[catch {set tt [clock scan $timev]}]} {
 	tellError {} {JoinAt Error} "Bad time specification in -joinat\
-for channel [$this name] - \"$time\""
+for channel [$this name] - \"$timev\""
 	return 0
     }
     set now [clock seconds]
     if {$now >= $tt} { incr tt [expr {24*60*60}] }
     if {$now >= $tt} {
-	tellError {} {JoinAt Error} "Past time in -joinat for channel [$this name] - \"$time\""
+	tellError {} {JoinAt Error} "Past time in -joinat for channel [$this name] - \"$timev\""
 	return 0
     }
     after [expr {($tt - $now) * 1000}] "$this sendJoin"
-    set cdata(joinat) $time
+    set cdata(joinat) $timev
     return 1
 }
 #
