@@ -1,12 +1,12 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1999/07/01 08:33:08 $
-# $Revision: 1.18.1.105 $
+# $Date: 2001/07/10 15:36:10 $
+# $Revision: 1.18.1.109 $
 #
 #
 package provide zircon 1.18
 #
-proc busyFlag {net} { $net configure -busy [expr ![$net busy]] }
+proc busyFlag {net} { $net configure -busy [expr {![$net busy]}] }
 #
 proc control_configure {this args} { confObj $this $args }
 #
@@ -74,7 +74,7 @@ proc control_askServer {this} {
 proc leaveZircon {} {
     set quits 1
     foreach x [Net :: list] {
-	if {[$x active]} { set quits [expr ($quits & [$x quit])] }
+	if {[$x active]} { set quits [expr {($quits & [$x quit])}] }
 	switch {} [$x confChange] {} default {
 	    if {[askUser SAVECONF {Save Configuration} \
 	      "You have made changes to the configuration of \
@@ -97,7 +97,7 @@ proc control_blackit {this opt} {
 }
 #
 proc flagit {net opt w} {
-    set rd [[$this net] setcolour]
+    set rd [$net setcolour]
     if {[$net $opt]} {$w.$opt configure -foreground $rd -activeforeground $rd }
 }
 #
@@ -123,7 +123,7 @@ proc delFromConf {name} {
     $mn.nets delete $indx
 }
 #
-proc nickKeys {net win} {
+proc nickKeys {unusednet win} {
     foreach y [list exclam quotedbl sterling dollar percent ampersand \
       asterisk parenleft parenright plus equal notsign acute grave at apostrophe \
       numbersign asciitilde colon less greater comma period question slash] {
@@ -316,13 +316,13 @@ proc faves {net} {
     }
 }
 #
-proc favecheck {menu chan} {
+proc favecheck {gmenu chan} {
     if {[$chan active]} {
-	foreach e {4 6} { $menu entryconfigure $e -state normal }
-	foreach e {1 3 5} { $menu entryconfigure $e -state disabled }
+	foreach e {4 6} { $gmenu entryconfigure $e -state normal }
+	foreach e {1 3 5} { $gmenu entryconfigure $e -state disabled }
     } {
-	foreach e {4 6} { $menu entryconfigure $e -state disabled }
-	foreach e {1 3 5} { $menu entryconfigure $e -state normal }
+	foreach e {4 6} { $gmenu entryconfigure $e -state disabled }
+	foreach e {1 3 5} { $gmenu entryconfigure $e -state normal }
     }
 }
 #
@@ -412,7 +412,7 @@ proc control_undernet {this flag} {
 	if {$six < 0} {
 	    $smn insert $st command -label [trans flags] \
 	      -command "underflags [$this net]"
-	    $smn insert [expr $st + 2] command -label [trans map] \
+	    $smn insert [expr {$st + 2}] command -label [trans map] \
 	      -command "[$this net] q1Send MAP"
 	    $umn insert 4 command -label [trans silence] \
 	      -command "underSilence [$this net]"
@@ -474,12 +474,16 @@ proc control_serverFrame {this ctl} {
     if {[info exists Ops(server)]} { $this buildServers $net $nf 1 0}
     button $nf.wallops -text Wallops -command "$net toggleFlag wallops"
     button $nf.srvmsg -text SrvMsg -command "$net toggleFlag srvmsg"
-    grid $nf.servers - $nf.wallops $nf.srvmsg -sticky ew
-    $this configure -smrow [expr [lindex [grid size $ctl] 1] - 1]
+    if {[$net nowallop] || ($srv != {nil} && [$srv nowallop])} {
+	grid $nf.servers - $nf.srvmsg - -sticky ew
+    } {
+	grid $nf.servers - $nf.wallops $nf.srvmsg -sticky ew
+    }
+    $this configure -smrow [expr {[lindex [grid size $ctl] 1] - 1}]
     grid [frame $nf.svc -borderwidth 0] - - - -sticky ew
 }
 #
-proc control_buildServers {this net ctl row col} {
+proc control_buildServers {unusedthis net ctl unusedrow unusedcol} {
     global Ops zircon
     switch $zircon(serversStyle) {
     panel {
@@ -503,7 +507,7 @@ proc control_buildServers {this net ctl row col} {
     }
 }
 #
-proc control_buildUsers {this net ctl row} {
+proc control_buildUsers {unusedthis net ctl unusedrow} {
     global Ops zircon
     switch $zircon(usersStyle) {
     pulldown {
@@ -562,7 +566,7 @@ proc nsSubMenu {m name w} {
 proc addToNsM {name} {
     set m [MainControl].helpFrm.spaces.menu
     set i 0
-    while 1 {
+    while {1} {
 	if {[catch {set nm [$m entrycget $i -label]}]} break
 	if {[string compare $name $nm] < 0} break
 	incr i
@@ -575,7 +579,7 @@ proc addToNsM {name} {
 proc delFromNsM {name} {
     set m [MainControl].helpFrm.spaces.menu
     set i 0
-    while 1 {
+    while {1} {
 	if {[catch {set nm [$m entrycget $i -label]}]} return
 	switch -- $name $nm break
 	incr i
@@ -611,7 +615,7 @@ proc addToNM {name} { addNS [MainControl].helpFrm.spaces.menu $name }
 proc setUnload {name state} {
     set m [MainControl].helpFrm.spaces.menu
     set i 0
-    while 1 {
+    while {1} {
 	if {[catch {set nm [$m entrycget $i -label]}]} return
 	switch -- $name $nm break
 	incr i
