@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/IRC.tcl,v $
-# $Date: 2000/03/30 13:14:51 $
-# $Revision: 1.18.1.61 $
+# $Date: 2002/01/18 12:22:23 $
+# $Revision: 1.18.1.64 $
 #
 package provide zircon 1.18
 #
@@ -17,9 +17,9 @@ proc ctcpAnswer {net usr nk cp} {
 	if {[$x active] && [[$x wid] visible]} {lappend chn $x}
     }
     regsub -all "\[\x01-\x1f\]" $nk {} nk
-    switch {} $chn {
+    if {$chn == {}} {
 	tellInfo $net {CTCP Reply} "CTCP Reply from $nk:\n$cp" CTCP
-    } default {
+    } {
 	foreach x $chn {
 	    $x addText @CTCP "*** CTCP Reply from $nk: $cp"
 	}
@@ -28,7 +28,7 @@ proc ctcpAnswer {net usr nk cp} {
 #
 proc ircERROR {net prefix param pargs} { $net error $prefix $param $pargs }
 #
-proc ircPONG {net prefix param pargs} { $net handlePong }
+proc ircPONG {net unusedprefix unusedparam unusedpargs} { $net handlePong }
 #
 proc mungNotice {msg} {
     if {[regexp \
@@ -61,7 +61,7 @@ proc ircNOTICE {net prefix param pargs} {
 	}
     } default {
 	set nk [$usr name]
-	while [regexp "(\[^\001\]*)\001(\[^\001\]*)\001(.*)" $param sub a cp b] {
+	while {[regexp "(\[^\001\]*)\001(\[^\001\]*)\001(.*)" $param sub a cp b]} {
 	    switch -glob -- $cp {
 	    {ZIRCON Sorry*} { }
 	    {PING *} {ctcpAnswer $net $usr $nk "PING - [pingVal $cp]"}
@@ -115,8 +115,8 @@ proc doPatterns {where prefix param} {
     regsub {^:} $prefix {} prefix
     foreach p [$where patterns] {
 	set pt [lindex $p 0]
-	if {[regexp -nocase [lindex $pt 0] $prefix] && \
-	  [regexp [lindex $pt 1] $param]} {
+	if {[regexp -nocase -- [lindex $pt 0] $prefix] && \
+	  [regexp -- [lindex $pt 1] $param]} {
 	    uplevel #0 set 0 [list $prefix]
 	    uplevel #0 set 1 [list [$where name]]
 	    uplevel #0 set 2 [list $param]
@@ -265,12 +265,12 @@ proc ircPART {net prefix param pargs} {
     handleOn $net LEAVE [list $chn $prefix $param]
 }
 #
-proc netsplit {string} {
+proc netsplit {str} {
     return [regexp -nocase \
-      {^([a-z0-9*_-]+\.)+([a-z0-9_-]+) ([a-z0-9*_-]+\.)+([a-z0-9_-]+)$} $string]
+      {^([a-z0-9*_-]+\.)+([a-z0-9_-]+) ([a-z0-9*_-]+\.)+([a-z0-9_-]+)$} $str]
 }
 #
-proc ircQUIT {net prefix param pargs} {
+proc ircQUIT {net prefix param unusedpargs} {
     if {![lindex [set nkinfo [mungPrefix $net $prefix]] 1]} {
 	set nk [[set usr [lindex $nkinfo 0]] name]
 	if {![$net nosplit] && [netsplit $param]} {
@@ -309,7 +309,7 @@ proc ircQUIT {net prefix param pargs} {
 proc ircKICK {net prefix param pargs} {
     set kicker [lindex [mung1Prefix $net $prefix] 0]
     set chan [lindex $pargs 0]
-    [set who [User :: make $net [set nk [lindex $pargs 1]]]] ref
+    set who [[User :: make $net [set nk [lindex $pargs 1]]] ref]
     set id [Channel :: find $chan $net]
     if {[$net me $who]} {
 	$id optText KICKME "*** You have been kicked off channel $chan by $kicker ($param)"
@@ -331,7 +331,7 @@ proc ircKICK {net prefix param pargs} {
    $who deref
 }
 #
-proc ircINVITE {net prefix param pargs} {
+proc ircINVITE {net prefix param unusedpargs} {
     if {![ignoreSet [lindex [set nkinfo [mungPrefix $net $prefix]] 3] invites]} {
 	set name [[lindex $nkinfo 0] name]
 	if {[askUser {} Invitation  "$name invites you to channel $param."]} {
@@ -346,7 +346,7 @@ proc ircINVITE {net prefix param pargs} {
 #
 proc ircKILL {net prefix param pargs} {
     set killer [lindex [mung1Prefix $net $prefix] 0]
-    [set who [User :: make $net [lindex $pargs 0]]] ref
+    set who [[User :: make $net [lindex $pargs 0]] ref]
     $who off
     set nk [$who name]
     if {[$net me $who]} {
@@ -374,7 +374,7 @@ proc ircTOPIC {net prefix param pargs} {
     handleOn $net TOPIC [list $chan $prefix $param]
 }
 #
-proc ircWALLOPS {net prefix param pargs} {
+proc ircWALLOPS {net prefix param unusedpargs} {
    $net display WALLOP "[getDate] $prefix (WALLOPS) - $param"
    handleOn $net WALLOP [list $prefix $param]
 }
@@ -401,11 +401,11 @@ proc mungPrefix {net prefix} {
     if {![regexp {^:([^!]+)!(.*)} $prefix m1 nk nm]} {
 	return [list nil 0 {} {}]
     }
-    [set usr [User :: make $net $nk $nm]] ref
+    set usr [[User :: make $net $nk $nm] ref]
     return [list $usr [$net me $usr] $nm [z_ignore $usr $nm]]
 }
 #
-proc mung1Prefix {net prefix} {
+proc mung1Prefix {unusednet prefix} {
     if {![regexp {^:([^!]+)!(.*)} $prefix m1 nk nm]} {
 	set nk [string range $prefix 1 end]
 	set nm {}
