@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/catless/Zircon/lib/RCS/Mac.tcl,v $
-# $Date: 1998/02/09 16:56:41 $
-# $Revision: 1.18.1.7 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Mac.tcl,v $
+# $Date: 2000/03/30 13:14:51 $
+# $Revision: 1.18.1.9 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 #
@@ -23,7 +23,13 @@ proc tmpdir {} {
 #
 proc prefdir {} {global env ; return [file join $env(PREF_FOLDER) Zircon]}
 #
-proc username {} { global env ; return $env(USER) }
+proc username {} {
+    global env tcl_platform
+    if {[info exists tcl_platform(user)]} {
+        return $tcl_platform(user)
+    }
+    return $env(USER)
+}
 #
 # No DCC on the Mac at the moment.
 #
