@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 2000/03/31 10:41:04 $
-# $Revision: 1.18.1.166 $
+# $Date: 2001/07/12 15:35:50 $
+# $Revision: 1.18.1.171 $
 #
 package provide zircon 1.18
 #
@@ -12,6 +12,7 @@ proc Net {name args} {
     upvar #0 $this ndata
     set XTO([string tolower $name]) $this
     if {[info exists defaultNet]} {
+        # FRINK : nocheck
 	array set ndata [array get $defaultNet]
 	array set ndata {
 	    channels	{}
@@ -59,7 +60,7 @@ proc net_irc322 {this prefix param pargs} {
     [$this listid] irc322 $prefix $param $pargs
 }
 #
-proc net_irc323 {this prefix param pargs} { [$this listid] process }
+proc net_irc323 {this unusedprefix unusedparam unusedpargs} { [$this listid] process }
 #
 proc net_eval {this cmd} {
     global currentNet
@@ -78,7 +79,7 @@ proc net_trimNick {this nk} {
     if {$ndata(nicksize)} {
 	set uh {}
 	regexp {(.*)(@.*)} $nk m nk uh
-	return [string range $nk 0 [expr $ndata(nicksize) - 1]]$uh
+	return [string range $nk 0 [expr {$ndata(nicksize) - 1}]]$uh
     }
     return $nk
 }
@@ -357,7 +358,7 @@ proc net_startIRC {this srv args} {
 	    }
 	}
     }
-# This point is never reached
+    # PRAGMA: notreached
 }
 #
 proc net_abort {this sock} {
@@ -382,13 +383,13 @@ proc net_afterCon {this sock} {
     set STN($sock) $this
     set ndata(sock) $sock
     set srv $ndata(hostid)
-    switch nil $srv {$this closeSock {} ; return 0}
+    switch nil $srv {$this closeSock {} ; return }
     if {![info exists host]} {set host [info hostname]}
     set server [$srv host]
     set passwd [$srv passwd]
-    foreach ln [$srv script] { if {[catch {$this q1Send $ln}]} return }
+    foreach ln [$srv script] { if {[catch {$this q1Send $ln}]} return}
     fileevent $sock readable "ircInput r $sock" 
-    switch {} $passwd {} default { if {[$this q1Send "PASS $passwd"]} return }
+    switch {} $passwd {} default { if {[$this q1Send "PASS $passwd"]} return}
     if {[$this q1Send "USER $user $host $server :[$this getIrcname]"]} {
 	# not connected....
 	return
@@ -556,7 +557,7 @@ proc startReconn {net srv msg} {
 #
 proc stopReconn {this} {
     upvar #0 $this ndata
-    if [info exists ndata(reconaft)] {
+    if {[info exists ndata(reconaft)]} {
 	catch {after cancel $ndata(reconaft)}
 	unset ndata(reconaft)
     }
@@ -633,6 +634,7 @@ proc net_ircTests {this} {
     if {!$ndata(away) && $ndata(autoAway) && $ndata(idle) > $ndata(autoAway)} {
 	$this AWAY {is away}
     }
+    # PRAGMA : array wus
     foreach id [array names MkOp] {
 	if {![string match {} [info procs $id]] && [$id active] && [$id operator]} {
 	    set flag +
@@ -822,7 +824,7 @@ proc net_NAMES {this chan} { $this q1Send "NAMES :$chan" }
 #
 proc net_PING {this srv} { $this q1Send "PING :$srv"}
 #
-proc net_error {this prefix param pargs} {
+proc net_error {this unusedprefix param unusedpargs} {
     set hst [$this host]
     if {[$this startup]} {
 	set msg "Cannot connect to $hst : $param"
@@ -899,7 +901,7 @@ proc net_clearMsgs {this usrs} {
 	foreach frd $mc {
 	    set nm [$frd name]
 	    foreach x {Message Notice} {
-		switch nil [set chn [$x :: find $nm $net]] continue
+		switch nil [set chn [$x :: find $nm $this]] continue
 		$chn doLeave {}
 	    }
 	}
@@ -907,13 +909,13 @@ proc net_clearMsgs {this usrs} {
     }
 }
 #
-proc net_fileProcess {this file usr} {
+proc net_fileProcess {this pfile usr} {
     foreach x [$this helpers] {
-	if {[regexp [lindex $x 0] $file]} {
+	if {[regexp -- [lindex $x 0] $pfile]} {
 	    set cmd [lindex $x 1]
 	    set np [lindex $x 2]
-	    if {[regexp -nocase $np [$usr name]]} {
-		regsub -all %s $cmd $file cmd
+	    if {[regexp -nocase -- $np [$usr name]]} {
+		regsub -all %s $cmd $pfile cmd
 		if {[catch {eval exec $cmd &} msg]} {
 	    	    tellError {} Error "Error executing helper cmd $cmd - $msg"
 		}
