@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/catless/Zircon/lib/RCS/Notice.tcl,v $
-# $Date: 1998/04/28 13:15:29 $
-# $Revision: 1.18.1.35 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Notice.tcl,v $
+# $Date: 2001/07/10 15:36:12 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -29,7 +29,7 @@ proc notice_call {this op pars} {
 proc makeNotice {chan net} {
     global defNotice
     set this [objName Notice]
-    proc $this {op args} "notice_call $this \$op \$args "
+    proc $this {unusedop args} "notice_call $this \$unusedop \$args "
     initObj $this Channel Notice
     set lchan [string tolower $chan]
     upvar #0 $this ndata NTO$net NTO
@@ -62,7 +62,7 @@ proc makeNotice {chan net} {
     return $this
 }
 #
-proc notice_onShow {this} { }
+proc notice_onShow {unusedthis} { }
 #
 proc notice_setTitles {this} {
     set nam [$this name]
@@ -125,7 +125,7 @@ proc Notice_find {nk net} {
 #
 proc Notice_save {desc net} { defSave $desc defNotice $net Notice }
 #
-proc notice_save {this desc} { }
+proc notice_save {unusedthis unuseddesc} { }
 #
 proc notice_leave {this} {
     set chan [$this name]
