@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Server.tcl,v $
-# $Date: 2000/02/21 10:30:10 $
-# $Revision: 1.18.1.33 $
+# $Date: 2001/06/13 07:20:27 $
+# $Revision: 1.18.1.35 $
 #
 #
 package provide zircon 1.18
@@ -147,12 +147,11 @@ proc Server_make {net host} {
 }
 #
 proc server_pack {this net} {
-    upvar #0 new$this new
+    upvar #0 new$this new ${net}STO STO
     foreach v {host port ip oper operpw script name passwd invisible wallops srvmsg} {
 	set new($v) [$this $v]
     }
-    global ${net}STO
-    set ${net}STO([string tolower [$this name]]) $this
+    set STO([string tolower [$this name]]) $this
 }
 #
 proc server_unpack {this net} {
