@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/User.tcl,v $
-# $Date: 1998/05/07 11:01:25 $
-# $Revision: 1.18.1.43 $
+# $Date: 2002/01/18 12:22:24 $
+# $Revision: 1.18.1.47 $
 #
 package provide zircon 1.18
 #
@@ -30,10 +30,12 @@ proc user_configure {this args} {
     }
 }
 #
-proc user_ref {this} { uplevel #0 incr ${this}(refcount) }
+proc user_ref {this} { uplevel #0 incr ${this}(refcount) ; return $this }
 #
 proc user_deref {this} { uplevel #0 incr ${this}(refcount) -1 }
 #
+proc user_use {this}  { $this ref ; return $this }
+#
 proc user_delete {this} {
     upvar #0 $this udata
     $udata(net) deregister users $this
@@ -54,7 +56,7 @@ proc user_substitute {this orig} {
     upvar #0 AChat[$this net] AChat
     if {[info exists AChat($this)]} { 
 	$orig ref
-	set AChat($orig) $Achat($this)
+	set AChat($orig) $AChat($this)
 	unset AChat($this)
     }
     $this deref
@@ -141,20 +143,18 @@ proc user_pack {this net} {
 }
 #
 proc user_unpack {this net} {
-    upvar #0 new$this newu
+    upvar #0 new$this newu ${net}UTO UTO
     foreach v {name notify menu id} {$this configure -$v $newu($v)}
-    unset newu
-    global ${net}UTO
-    unset ${net}UTO([$this lname])
+    unset newu UTO([$this lname])
 }
 #
 # Procs for the class User
 #
-#
 proc User_find {nk net} {
     upvar #0 UTO$net UTO
     set name [string tolower [$net trimNick $nk]]
-    if {[info exists UTO($name)]} { return $UTO($name) } { return nil }
+    if {[info exists UTO($name)]} { return $UTO($name) }
+    return nil
 }
 #
 proc User_make {net nk args} {
