@@ -1,7 +1,7 @@
 
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/ctcp.tcl,v $
-# $Date: 1998/10/29 13:59:38 $
-# $Revision: 1.18.1.38 $
+# $Date: 2001/06/13 07:20:28 $
+# $Revision: 1.18.1.39 $
 #
 package provide zircon 1.18
 #
@@ -14,7 +14,7 @@ proc ctcpReply {net chan nk op str} {
 #
 proc handleCTCP {net op chid chan usr prefix ign param} {
     if {[ignoreSet $ign ctcp]} { return {}}
-    if {![regexp [$net ctcpPattern] $chan]} { return {} }
+    if {![regexp -- [$net ctcpPattern] $chan]} { return {} }
     handleOn $net CTCP [list $op $prefix $param $chan]
     global zircon
     set nk [$usr name]
