@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/dialog.tcl,v $
-# $Date: 1998/07/10 13:34:00 $
-# $Revision: 1.18.1.40 $
+# $Date: 2001/07/10 15:36:13 $
+# $Revision: 1.18.1.43 $
 #
 package provide zircon 1.18
 #
@@ -26,7 +26,7 @@ proc doButtons {w plv pars} {
 	    switch {} [set cmd [lindex $arg 1]] {} default {append cmd " $param"}
 	    switch -glob -- [set lbl [lindex $arg 0]] {
 	    -* {
-		    set lbl [trans [string index $lbl 1 end]]
+		    set lbl [trans [string range $lbl 1 end]]
 		    button $w.bot.$i -text $lbl -width 7 -command $cmd
 		}
 	    default {
@@ -117,7 +117,7 @@ proc mkDialog {kind w title msgText entries args} {
 	}
 	if {[set ti [listmember [$net toInfo] $kind]] || [listmember [$net alwayslog] $kind]} {
 	    $net inform $msgText
-	    if {$ti} return {}
+	    if {$ti} { return {} }
 	}
     }
     switch {} $w {set w .@[newName dlg]} default {killWindow $w}
@@ -359,7 +359,8 @@ proc killFWindow {w} {
 #
 #
 proc warnUser {t m} {
-    switch [tk_dialog .@[newName wu] $t $m warning 0 ok cancel] 0 {return 1} 1 {return 0}
+    if {[tk_dialog .@[newName wu] $t $m warning 0 ok cancel] == 0} {return 1}
+    return 0
 }
 #
 proc askUser {kind t m} {
@@ -367,7 +368,8 @@ proc askUser {kind t m} {
 	global currentNet
 	if {[listmember [$currentNet noConfirm] $kind]} { return 1 }
     }
-    switch [tk_dialog .@[newName au] $t $m question 0 yes no] 0 {return 1} 1 {return 0}
+    if {[tk_dialog .@[newName au] $t $m question 0 yes no] == 0} {return 1}
+    return 0
 
 }
 #
