@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/main.tcl,v $
-# $Date: 1999/05/17 09:34:56 $
-# $Revision: 1.18.1.92 $
+# $Date: 2001/07/10 15:36:13 $
+# $Revision: 1.18.1.96 $
 #
 package provide zircon 1.18
 #
@@ -21,16 +21,6 @@ proc playBell {this tag} {
     }
 }
 #
-proc setScroll {id txt win total window} {
-    upvar #0 ${id}(scrollback) sb
-    if {$total > $sb} {
-	incr total -$sb
-	$txt delete 1.0 "1.0 + $total lines"
-	set total $sb
-    }
-    $win set $total $window
-}
-#
 # alter menu item states - used for oping and ircoping
 #
 proc setState {name pick state} {
@@ -152,7 +142,7 @@ proc irc004 {net prefix param pargs} {
     if {$srvmsg} {
 	    set ctl [[$net control] window]
 	    if {[info exists $ctl.cr.srvmsg]} {
-		grid $w.srvmsg -row [[$this control] smrow] -column 3 -sticky ew
+		grid $ctl.srvmsg -row [[$net control] smrow] -column 3 -sticky ew
 	    }
 	    $net setFlag srvmsg
 	    [$net control] del2.9stuff
@@ -320,7 +310,9 @@ proc afterMOTD {net prefix param pargs} {
     if {[$net motdSeen]} return
     global zircon defMsg
     $net setFlag invisible
-    $net setFlag wallops
+    if {![$net nowallop] && ![[$net hostid] nowallop]} {
+	$net setFlag wallops
+    }
     if {!$zircon(j)} {
 	foreach id [$net channels] {
 	    switch $id [getDefault defChan $net] {} default {
@@ -350,7 +342,8 @@ proc irc251 {net prefix param pargs} {
 }
 #
 proc isAre {nm msg} {
-    switch 1 $nm {return "is 1 $msg"} default {return "are $nm ${msg}s"}
+    if {1 == $nm} {return "is 1 $msg"}
+    return "are $nm ${msg}s"
 }
 #
 proc irc252 {net prefix param pargs} {
