@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/tcl84.tcl,v $
-# $Date: 2001/07/20 06:52:42 $
-# $Revision: 1.18.1.3 $
+# $Date: 2002/03/13 13:56:13 $
+# $Revision: 1.18.1.4 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -66,3 +66,8 @@ proc native {fl} { return [file nativename $fl] }
 proc ncsort {lst} { return [lsort -dictionary $lst] }
 #
 proc safeUnset {args} { foreach x $args { uplevel #0 unset -nocomplain [list $x] }}
+
+::tk::unsupported::ExposePrivateCommand tkEntryInsert
+::tk::unsupported::ExposePrivateCommand tkEntryBackspace
+::tk::unsupported::ExposePrivateCommand tkEntrySeeInsert
+
