@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/chat.tcl,v $
-# $Date: 1998/04/23 13:09:01 $
-# $Revision: 1.18.1.9 $
+# $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/chat.tcl,v $
+# $Date: 1998/09/02 12:57:38 $
+# $Revision: 1.18.1.11 $
 #
 package provide Dcc 1.18
 #
@@ -45,7 +45,7 @@ proc dccChat {mode conn} {
 proc user_unChServ {this} {
     upvar #0 AChat[$this net] AChat
     if {[info exist AChat($this)]} {
-	catch {uplevel #0 unset $AChat($this)}
+	safeUnset $AChat($this)
 	catch {close $AChat($this)}
 	unset AChat($this)
     }
@@ -53,5 +53,7 @@ proc user_unChServ {this} {
 #
 proc user_unChat {this} {
     $this unChServ
-    switch nil [set id [Chat :: find [$this name] [$this net]]] {} default {$id delete}
+    switch nil [set id [Chat :: find [$this name] [$this net]]] {} default {
+	catch {$id delete}
+    }
 }
